% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_3.R
\docType{data}
\name{test_mod2}
\alias{test_mod2}
\title{Sample Dataset: A Path Model With A Moderator}
\format{
A data frame with 300 rows and 6 variables:
\describe{
\item{dv}{Dependent variable, continuous}
\item{iv}{Independent variable, continuous}
\item{med}{Mediator, continuous}
\item{mod}{Moderator, continuous}
\item{cov1}{Covariate, continuous}
\item{cov2}{Covariate, continuous}
}
}
\usage{
test_mod2
}
\description{
For testing. Generated from the following
model.

\if{html}{\out{<div class="sourceCode">}}\preformatted{mod <-
"
med ~ iv + cov1
dv ~ med + mod + med:mod + cov2
"
}\if{html}{\out{</div>}}
}
\keyword{datasets}
